@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dbi.mli,v 1.25 2005/01/25 17:59:10 ChriS Exp $
+ * $Id: dbi.mli,v 1.27 2005/11/17 09:56:53 rwmj Exp $
  *)
 
 (** Generic database interface.
@@ -114,6 +114,8 @@ end
 (* Some types not yet implemented. XXX *)
 type sql_t = [ `Null			(* NULL value *)
 	     | `Int of int		(* integer, smallint *)
+	     | `Int32 of int32		(* 32-bit integer [not used] *)
+	     | `Int64 of int64		(* int8, serial *)
              | `Float of float		(* double precision, real *)
 	     | `String of string	(* char, varchar, text *)
 	     | `Bool of bool		(* boolean *)
@@ -157,23 +159,21 @@ type postrollback_handle
 (** {1 SQL utility functions.} *)
 
 val string_escaped : string -> string
-(** [escape_string s] escapes the string [s] according to SQL rules
-  * and surrounds it with single quotes.  This should be hardly needed
-  * as the data provided through the sql_t types will automatically be
-  * escaped for you.
-  *)
+  (** [escape_string s] escapes the string [s] according to SQL rules
+      and surrounds it with single quotes.  This should be hardly needed
+      as the data provided through the sql_t types will automatically be
+      escaped for you.  *)
 
 val placeholders : int -> string
-(** [placeholders n] returns a string of the form "(?, ?, ..., ?)" containing
-  * [n] question marks.
-  * @raise Invalid_argument if [n <= 0].
-  *)
+  (** [placeholders n] returns a string of the form "(?, ?, ..., ?)"
+      containing [n] question marks.
+
+      @raise Invalid_argument if [n <= 0].  *)
 
 exception SQL_error of string
-(** Exceptions thrown by subclasses on SQL errors. *)
+  (** Exceptions thrown by subclasses on SQL errors. *)
 
-class virtual statement :
-  connection ->
+class virtual statement : connection ->
 object
   method virtual execute : sql_t list -> unit
     (** Execute the statement with the given list of arguments substituted
@@ -236,7 +236,7 @@ object
       * (column name, value).
       * @raise Not_found if there are no more rows to fetch. *)
 
-  method virtual serial : string -> int
+  method virtual serial : string -> int64
     (** If the statement is an INSERT and has been executed, then some
       * databases support retrieving the serial number of the INSERT
       * statement (assuming there is a SERIAL column or SEQUENCE attached
