@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dbi_mysql.ml,v 1.6 2004/08/03 16:49:41 rwmj Exp $
+ * $Id: dbi_mysql.ml,v 1.7 2005/09/08 14:46:05 rwmj Exp $
  *)
 
 open Printf
@@ -92,7 +92,7 @@ object (self)
                     | `Float f ->
                         string_of_float f
 		    | `String s ->
-			Mysql.escape s
+			"'" ^ Mysql.escape s ^ "'"
 		    | `Bool b ->
 			if b then "'t'" else "'f'"
 		    | _ ->
