@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dbi_sqlite.ml,v 1.4 2004/12/21 17:01:06 ChriS Exp $
+ * $Id: dbi_sqlite.ml,v 1.5 2005/11/17 09:56:53 rwmj Exp $
  *)
 
 open Printf
@@ -25,8 +25,10 @@ open Printf
 (* [encode_sql_t v] returns a string suitable for substitution of "?"
    in a SQL query. *)
 let encode_sql_t = function
-  | `Null -> "NULL"
+  | `Null -> "null"
   | `Int i -> string_of_int i
+  | `Int32 i -> Int32.to_string i
+  | `Int64 i -> Int64.to_string i
   | `Float f -> string_of_float f
   | `String s -> Dbi.string_escaped s
   | `Bool b -> if b then "T" else "F" (* XXX *)
