@@ -1,8 +1,8 @@
-(* $Id: make-connection.ml,v 1.1 2004/08/05 13:40:59 rwmj Exp $ *)
+(* $Id: make-connection.ml,v 1.2 2005/11/17 09:56:53 rwmj Exp $ *)
 
 open Printf
 
-module DB = Dbi_postgres
+module DB = Dbi_postgresql
 
 let () =
   (* Supply the name of the database on the command line. *)
