@@ -1,4 +1,4 @@
-(* $Id: simple-insert.ml,v 1.1 2004/08/05 13:40:59 rwmj Exp $ *)
+(* $Id: simple-insert.ml,v 1.2 2005/11/17 09:56:53 rwmj Exp $ *)
 
 open Printf
 
@@ -22,15 +22,15 @@ let () =
                          values (?, ?, ?)" in
 
   sth#execute [`String "Bruce"; `Int 8000; `Int 3 ];
-  printf "Bruce's employee ID is %d\n" (sth#serial "employees_id_seq");
+  printf "Bruce's employee ID is %Ld\n" (sth#serial "employees_id_seq");
 
   sth#execute [`String "Fred"; `Int 8000; `Int 3 ];
-  printf "Fred's employee ID is %d\n" (sth#serial "employees_id_seq");
+  printf "Fred's employee ID is %Ld\n" (sth#serial "employees_id_seq");
 
   sth#execute [`String "Hannah"; `Int 8000; `Int 3 ];
-  printf "Hannah's employee ID is %d\n" (sth#serial "employees_id_seq");
+  printf "Hannah's employee ID is %Ld\n" (sth#serial "employees_id_seq");
 
   sth#execute [`String "Stephanie"; `Int 8000; `Int 3 ];
-  printf "Stephanie's employee ID is %d\n" (sth#serial "employees_id_seq");
+  printf "Stephanie's employee ID is %Ld\n" (sth#serial "employees_id_seq");
 
   print_employees "After taking on new employees" dbh
